/* ----------------------------------------------------------------------
 * Project:	 CMSIS DSP Library
 * Title:	 arm_cfft_f32.c
 * Description:	 Combined Radix Decimation in Frequency CFFT Floating point processing function
 * Target Processor: Cortex-M and Cortex-A cores
 * -------------------------------------------------------------------- */

#include "transform_functions.h"
#include "arm_common_tables.h"

extern void   arm_radix8_butterfly_f32( float32_t * pSrc,
    uint16_t fftLen, const float32_t * pCoef, uint16_t twidCoefModifier );

extern void   arm_bitreversal_32( uint32_t * pSrc,
    const uint16_t bitRevLen, const uint16_t * pBitRevTable );

/**
  @brief	 Processing function for the floating-point complex FFT.
  @param[in]	 S		points to an instance of the floating-point CFFT structure
  @param[in,out] p1		points to the complex data buffer of size <code>2*fftLen</code>. Processing occurs in-place
  @return	 none
 */

void
arm_cfft_f32( const arm_cfft_instance_f32 * S, float32_t * p1 )
{
  uint32_t      L = S->fftLen;

  if ( L != 64 )
    return;
  
  arm_radix8_butterfly_f32( p1, L, ( float32_t * ) S->pTwiddle, 1 );
  
  arm_bitreversal_32( ( uint32_t * ) p1, S->bitRevLength, S->pBitRevTable );
}
